@@ -24,6 +24,8 @@
 #include <QDBusInterface>
 
 #include <NetworkManagerQt/Connection>
+#include <NetworkManagerQt/Settings>
+#include <NetworkManagerQt/ConnectionSettings>
 #if WITH_MODEMMANAGER_SUPPORT
 #include <ModemManagerQt/GenericTypes>
 #endif
@@ -84,6 +86,7 @@ public Q_SLOTS:
     void enableAirplaneMode(bool enable);
     void enableNetworking(bool enable);
     void enableWireless(bool enable);
+
     void enableWwan(bool enable);
 
     /**
@@ -118,6 +121,7 @@ private:
     QMap<QString, bool> m_bluetoothAdapters;
 
     void enableBluetooth(bool enable);
+
 };
 
 #endif // PLASMA_NM_HANDLER_H
