@@ -39,11 +39,11 @@ class OpenconnectAuthWidget : public SettingWidget
     Q_OBJECT
     Q_DECLARE_PRIVATE(OpenconnectAuthWidget)
 public:
-    explicit OpenconnectAuthWidget(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent = 0);
-    ~OpenconnectAuthWidget();
+    explicit OpenconnectAuthWidget(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent = nullptr);
+    ~OpenconnectAuthWidget() override;
     virtual void readSecrets();
     void readConfig();
-    virtual QVariantMap setting() const;
+    QVariantMap setting() const override;
 
 private:
     OpenconnectAuthWidgetPrivate * const d_ptr;
